/**
 * @file
 * Sidekick behaviors.
 */

(function ($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.sidekick = {
    attach: function (context, drupalSettings) {
      $('.sidekick-frame', context).find('iframe').parent().addClass('sidekick-frame__content');
      if (drupalSettings.sidekick) {
        var targetIframe = $('.sidekick-frame iframe', context).content;
        if (!!targetIframe) {
          targetIframe.contentWindow.postMessage(drupalSettings.sidekick.nodeDetails, '*');
        }
      }
    },
  };

  Drupal.behaviors.sidekickAjax = {
    attach: function (context, settings) {
      let ajax = null;
      ajax = findAjax();
      if (ajax) {
        ajax.success = function (response, status) {
          Drupal.Ajax.prototype.success.call(this, response, status);
        }
        ajax.progress = false;
      }
    }
  };

  Drupal.behaviors.sidekickMessaging = {
    attach: function (context, settings) {
      const $context = $(context);
      let $form = $context.find('form.sidekick-messaging-form');
      if ($form.length === 0) {
        $form = $context.parents('form.sidekick-messaging-form');
      }
      if ($form.length > 0) {
        if ($context.find('.ajax-new-content').length > 0) {
          if (!Drupal.ajax.instances.some(isAjaxing)) {
            triggerAjax();
          }
        }
        const inputs = $form.find(':input, [contenteditable="true"]')
          .not('button, input[type="button"]');
        $(once('sidekick-messaging-form', inputs))
          .on('change', function (event) {
            var $form = $(event.target).parents('.sidekick-messaging-form').first();
            if ($form.length) {
              if (!Drupal.ajax.instances.some(isAjaxing)) {
                triggerAjax();
              }
            }
          });
      }
    }
  };

  function findAjax() {
    let ajax = null;
    const selector = '#sidekick-messaging-button';
    for (const index in Drupal.ajax.instances) {
      if (Drupal.ajax.instances.hasOwnProperty(index)) {
        const ajaxInstance = Drupal.ajax.instances[index];
        if (ajaxInstance && (ajaxInstance.selector === selector)) {
          ajax = ajaxInstance;
          break;
        }
      }
    }
    return ajax;
  }

  function triggerAjax() {
    let ajax;
    ajax = findAjax();
    if (ajax) {
     $(ajax.element).trigger(ajax.element_settings ? ajax.element_settings.event : ajax.elementSettings.event);
    }
    if (drupalSettings.sidekick.sidekickData) {
      const targetIframe = $('.sidekick-frame iframe', context).content;
      if (!!targetIframe) {
        targetIframe.contentWindow.postMessage(drupalSettings.sidekick.sidekickData, '*');
      }
    }
  }

  function isAjaxing(instance) {
    return instance && instance.hasOwnProperty('ajaxing') && instance.ajaxing === true;
  }

}(jQuery, Drupal, drupalSettings));
