<?php

namespace Drupal\sidekick\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\OpenModalDialogCommand;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\sidekick\SidekickService;

/**
 * Returns responses for Sidekick routes.
 */
class SidekickController extends ControllerBase
{
    /**
     * The language manager.
     *
     * @var \Drupal\Core\Language\LanguageInterface
     */
    protected $language;

    /**
     * @var \Drupal\sidekick\SidekickService
     */
    protected $sidekick_service;

    /**
     * @param \Drupal\Core\Language\LanguageManagerInterface $language
     * @param \Drupal\sidekick\SidekickService $sidekick_service
     */
    public function __construct(
        LanguageManagerInterface $language,
        SidekickService $sidekick_service
    ) {
        $this->language = $language;
        $this->sidekick_service = $sidekick_service;
    }

    /**
     * {@inheritdoc}
     */
    public static function create(ContainerInterface $container)
    {
        return new static(
            $container->get('language_manager'),
            $container->get('sidekick.service')
        );
    }

    /**
     * Builds response.
     */
    public function build()
    {
        $language_code = $this->language
            ->getCurrentLanguage(LanguageInterface::TYPE_CONTENT)
            ->getId();

        $domain = Url::fromRoute(
            '<front>',
            [],
            ['absolute' => true]
        )->toString();

        $api_url = Url::fromUri(
            'https://assistant.ai-sidekick.app/chat',
            [
                'query' => $this->sidekick_service->getQueryParameter(
                    $language_code
                )
            ]
        )->toString();

        $iframe_attributes = [
            'title' => 'Sidekick',
            'class' => 'sidekick-iframe',
            'referrerpolicy' => 'origin',
            'allow' => 'clipboard-write',
        ];
        $iframe_attribute_string = http_build_query(
            $iframe_attributes,
            '',
            ' '
        );

        $content = '<iframe src="' . $api_url . '" ' . $iframe_attribute_string . '></iframe>';

        $response = new AjaxResponse();
        $response->addCommand(
            new OpenModalDialogCommand(
                'Sidekick',
                $content,
                ['width' => '80vw']
            )
        );

        return $response;
    }

}
